@@ -6,15 +6,17 @@ from .settings import preferences_settings
 
 
 class DynamicPreferencesConfig(AppConfig):
-    name = 'dynamic_preferences'
+    name = "dynamic_preferences"
     verbose_name = _("Dynamic Preferences")
+    default_auto_field = "django.db.models.AutoField"
 
     def ready(self):
         if preferences_settings.ENABLE_GLOBAL_MODEL_AUTO_REGISTRATION:
-            GlobalPreferenceModel = self.get_model('GlobalPreferenceModel')
+            GlobalPreferenceModel = self.get_model("GlobalPreferenceModel")
 
             preference_models.register(
-                GlobalPreferenceModel, global_preferences_registry)
+                GlobalPreferenceModel, global_preferences_registry
+            )
 
         # This will load all dynamic_preferences_registry.py files under
         # installed apps
