@@ -9,28 +9,29 @@ from .exceptions import NotFoundInRegistry
 
 
 class AbstractSinglePreferenceForm(forms.ModelForm):
-
     class Meta:
-        fields = ('section', 'name', 'raw_value')
+        fields = ("section", "name", "raw_value")
 
     def __init__(self, *args, **kwargs):
 
-        self.instance = kwargs.get('instance')
+        self.instance = kwargs.get("instance")
         initial = {}
         if self.instance:
-            initial['raw_value'] = self.instance.value
-            kwargs['initial'] = initial
+            initial["raw_value"] = self.instance.value
+            kwargs["initial"] = initial
         super(AbstractSinglePreferenceForm, self).__init__(*args, **kwargs)
 
         if self.instance.name:
-            self.fields['raw_value'] = self.instance.preference.setup_field()
-
+            self.fields["raw_value"] = self.instance.preference.setup_field()
 
     def clean(self):
         cleaned_data = super(AbstractSinglePreferenceForm, self).clean()
         try:
-            self.instance.name, self.instance.section = cleaned_data['name'], cleaned_data['section']
-        except KeyError: # changelist form
+            self.instance.name, self.instance.section = (
+                cleaned_data["name"],
+                cleaned_data["section"],
+            )
+        except KeyError:  # changelist form
             pass
         try:
             self.instance.preference
@@ -39,21 +40,24 @@ class AbstractSinglePreferenceForm(forms.ModelForm):
         return self.cleaned_data
 
     def save(self, *args, **kwargs):
-        self.instance.value = self.cleaned_data['raw_value']
+        self.instance.value = self.cleaned_data["raw_value"]
         return super(AbstractSinglePreferenceForm, self).save(*args, **kwargs)
 
-class SinglePerInstancePreferenceForm(AbstractSinglePreferenceForm):
 
+class SinglePerInstancePreferenceForm(AbstractSinglePreferenceForm):
     class Meta:
-        fields = ('instance',) + AbstractSinglePreferenceForm.Meta.fields
+        fields = ("instance",) + AbstractSinglePreferenceForm.Meta.fields
 
     def clean(self):
         cleaned_data = super(AbstractSinglePreferenceForm, self).clean()
         try:
-            self.instance.name, self.instance.section = cleaned_data['name'], cleaned_data['section']
-        except KeyError: # changelist form
+            self.instance.name, self.instance.section = (
+                cleaned_data["name"],
+                cleaned_data["section"],
+            )
+        except KeyError:  # changelist form
             pass
-        i = cleaned_data.get('instance')
+        i = cleaned_data.get("instance")
         if i:
             self.instance.instance = i
             try:
@@ -62,8 +66,8 @@ class SinglePerInstancePreferenceForm(AbstractSinglePreferenceForm):
                 raise ValidationError(NotFoundInRegistry.detail_default)
         return self.cleaned_data
 
-class GlobalSinglePreferenceForm(AbstractSinglePreferenceForm):
 
+class GlobalSinglePreferenceForm(AbstractSinglePreferenceForm):
     class Meta:
         model = GlobalPreferenceModel
         fields = AbstractSinglePreferenceForm.Meta.fields
@@ -84,15 +88,14 @@ def preference_form_builder(form_base_class, preferences=[], **kwargs):
             if isinstance(pref, string_types):
                 preferences_obj.append(registry.get(name=pref))
             elif type(pref) == tuple:
-                preferences_obj.append(
-                    registry.get(name=pref[0], section=pref[1]))
+                preferences_obj.append(registry.get(name=pref[0], section=pref[1]))
             else:
                 raise NotImplementedError(
-                    "The data you provide can't be converted to a Preference object")
-    elif kwargs.get('section', None):
+                    "The data you provide can't be converted to a Preference object"
+                )
+    elif kwargs.get("section", None):
         # Try to use section param
-        preferences_obj = registry.preferences(
-            section=kwargs.get('section', None))
+        preferences_obj = registry.preferences(section=kwargs.get("section", None))
 
     else:
         # display all preferences in the form
@@ -110,13 +113,13 @@ def preference_form_builder(form_base_class, preferences=[], **kwargs):
     for preference in preferences_obj:
         f = preference.field
         instance = manager.get_db_pref(
-            section=preference.section.name, name=preference.name)
+            section=preference.section.name, name=preference.name
+        )
         f.initial = instance.value
         fields[preference.identifier()] = f
         instances.append(instance)
 
-    form_class = type(
-        'Custom' + form_base_class.__name__, (form_base_class,), {})
+    form_class = type("Custom" + form_base_class.__name__, (form_base_class,), {})
     form_class.base_fields = fields
     form_class.preferences = preferences_obj
     form_class.instances = instances
@@ -144,7 +147,6 @@ class PreferenceForm(forms.Form):
             )
 
 
-
 class GlobalPreferenceForm(PreferenceForm):
 
     registry = global_preferences_registry
